@@ -105,7 +105,7 @@ class Domoticz(IPlugin):
 				log.msg(" total    :  %s" % (total))
 				total = range(total)
 				log.msg(" total - range    :  %s" % (total))
-				for xx in total:
+				for xx in jsonreq['result'] :
 					log.msg(" jsonreq - idx   :  %s" % (xx['idx']))
 					log.msg("   jsonreq - type   :  %s" % (xx['Type']))
 		if bodies == "":
